==> yy_core-1.0.0.tar.gz: yy_core-1.0.0/yy_core/models/db_models/asset/asset_only_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-07-15 17:17:08
@LastEditTime: 2023-12-29 13:38:20
@LastEditors: yy
@Description: 
"""

#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.models.cache_model import *

class AssetOnlyModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(AssetOnlyModel, self).__init__(AssetOnly, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_asset","redis_asset", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class AssetOnly:

    def __init__(self):
        super(AssetOnly, self).__init__()
        self.id = 0  # id
        self.id_md5 = 0  # id_md5(act_id+user_id+only_id)md5int生成
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动ID
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.only_id = ""  # 唯一标识(用于并发操作时校验避免重复操作)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'open_id', 'only_id', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "asset_only_tb"

==> yy_core-1.0.11.tar.gz: yy_core-1.0.11/yy_core/models/db_models/asset/asset_only_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-07-15 17:17:08
@LastEditTime: 2023-12-29 13:38:20
@LastEditors: yy
@Description: 
"""

#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.cache_model import *

class AssetOnlyModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(AssetOnlyModel, self).__init__(AssetOnly, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_asset","redis_asset", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class AssetOnly:

    def __init__(self):
        super(AssetOnly, self).__init__()
        self.id = 0  # id
        self.id_md5 = 0  # id_md5(act_id+user_id+only_id)md5int生成
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动ID
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.only_id = ""  # 唯一标识(用于并发操作时校验避免重复操作)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'open_id', 'only_id', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "asset_only_tb"
